from setuptools import setup, find_packages

setup(
    name='DePass',
    version='0.0.4',
    description='DePass: a dual-enhanced graph learning framework for paired data integration',
    packages=find_packages(),
    install_requires=[
        'anndata==0.9.2',
        'hnswlib==0.8.0',
        'matplotlib==3.7.1',
        'numpy==1.23.5',
        'pandas==1.5.3',
        'scanpy==1.9.8',
        'scikit-learn==1.3.0',
        'scipy==1.10.1',
        'seaborn==0.12.2',
        'torch==2.4.1',
        'torch-geometric==2.3.1',
        'torch-scatter==2.1.2',
        'tqdm==4.65.0',
        'jupyter',
    ],
    python_requires='==3.8.20',
)